##  2. Add New Fact Sheet Fields in the Maturity Subsection
In the Maturity subsection, introduce four new fields - Current Maturity, Target Maturity, Strategic Importance, and Maturity Description.
To add new fields in the Maturity subsection, follow these steps:
i. In the newly created Maturity subsection, click on the + Add field button.
ii. Depending on the Fact Sheet field you are creating, on the right-side panel, fill in the following values to the corresponding fields:
| Current Maturity | Target Maturity | Strategic Importance | Maturity Description
---|---|---|---|---
Key: | currentMaturity | targetMaturity | strategicImportance | maturityDescription
Type: | SINGLE_SELECT | SINGLE_SELECT | SINGLE_SELECT | STRING
Width: | M (4/12) | M (4/12) | M (4/12) | XXL (12/12)
Values: |
  * adhoc
  * repeatable
  * defined
  * managed
  * optimized

|
  * adhoc
  * repeatable
  * defined
  * managed
  * optimized

|
  * parity
  * tier2
  * tier1

|


![Adding a Fact Sheet field: Strategic Importance](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27423c7d7a4410149d64e94009bef48e_LowRes.gif)
Adding Fact Sheet field - Strategic Importance
iii. For the Current Maturity, Target Maturity, and Strategic Importance fields, choose an appropriate icon and color, and set the icon display order to Ascending.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274b28677a441014ba0996e0cde382b5_LowRes.png)
iv. Click Create to create the field.
v. Go to the Manage Translation tab (Globe icon) on the right-side panel. Depending on the Fact Sheet field you are creating, refer to the tables below and fill in the appropriate values to the Label, Field values, and Help text:
For the Current Maturity field, refer to the table below.
| Values | Help text values
---|---|---
Label: | Current Maturity |
adhoc: | Level 1 - Ad-hoc | Processes are largely manual and inconsistent. Success often depends on individual heroics.
repeatable: | Level 2 - Repeatable | Basic and consistent processes are established and can be repeated for similar projects.
defined: | Level 3 - Defined | Processes are automated and integrated across all processes for the organization.
managed: | Level 4 - Managed | Processes are automated and measured for success.
optimized: | Level 5 - Optimized | Processes yield consistent results and are continually optimized.


For the Target Maturity field, refer to the table below.
| Values | Help text values
---|---|---
Label: | Target Maturity |
adhoc: | Level 1 - Ad-hoc | Processes are largely manual and inconsistent. Success often depends on individual heroics.
repeatable: | Level 2 - Repeatable | Basic and consistent processes are established and can be repeated for similar projects.
defined: | Level 3 - Defined | Processes are automated and integrated across all processes for the organization.
managed: | Level 4 - Managed | Processes are automated and measured for success.
optimized: | Level 5 - Optimized | Processes yield consistent results and are continually optimized.


For the Strategic Importance field, refer to the table below.
| Values | Help text values
---|---|---
Label: | Strategic Importance |
parity: | Commodity | {{factSheet}} maintains commodity and operational needs, but does not provide any competitive advantage.
tier2: | Differentiation | {{factSheet}} is important to achieve excellence in order to compete with and differentiate from others.
tier1: | Innovation | {{factSheet}} is critical to competitive advantage.


For the Maturity Description field, refer to the table below.
| Values | Help text values
---|---|---
Label: | Maturity Description | Describes the result of the maturity analysis.


![Adding Translations to Strategic Importance Field](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2754910f7a441014891bb302de8eba05_LowRes.gif)
Adding Translations to Fact Sheet Field - Strategic Importance
vi. In the final tab of the right-side panel, toggle Include in views and Show in filters for the Current Maturity, Target Maturity, and Strategic Importance fields. To learn more about these options, see [Showing Fields in Views](https://help.sap.com/docs/leanix/ea/fact-sheet-fields?locale=en-US&state=PRODUCTION&version=CLOUD "Fact sheet fields are designed for storing information on specific data points. You can configure existing fields and create custom ones.") and [Showing Fields in Filters](https://help.sap.com/docs/leanix/ea/fact-sheet-fields?locale=en-US&state=PRODUCTION&version=CLOUD "Fact sheet fields are designed for storing information on specific data points. You can configure existing fields and create custom ones.").
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2756aea37a441014a9f5ad91895a2b3f_LowRes.png)
vii. Click Show changes, and then Apply to finish adding the new Fact Sheet field.
